@@ -6,12 +6,11 @@ from .Core.Terminal import Terminal
 class Crawler:
     def __init__(self, root) -> None:
         self.root = root
-        self.fetcher = Fetcher
+        self.fetcher = Fetcher()
 
 
     def crawl(self):
-        fetch = Fetcher()
-        response = fetch.get_page(self.root)
+        response = self.fetcher.get_page(self.root)
         if self.isError(response): 
             Terminal.error("Error at root")
             return
@@ -27,7 +26,7 @@ class Crawler:
     def _crawling_(self, response):
         scraper = Scraper(response)
         list_href = scraper.gethref()
-        if list_href.count == 0: return None
+        if list_href.count == 0 or not list_href: return None
         list_href.map(lambda x: x.url())
         list_href.forEach(lambda x: Terminal.found(x))
         responses = self.fetcher.get_all_pages(list_href)
