@@ -16,4 +16,4 @@ class href:
             return url
 
     def __str__(self) -> str:
-        return self.content
\ No newline at end of file
+        return self.url()
\ No newline at end of file
